<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Gdpr Cookie Graphql by Amasty
 */

namespace Amasty\GdprCookieGraphql\Model\Resolver\Bar\Processor;

use Amasty\GdprCookie\Model\ConfigProvider;
use Amasty\GdprCookie\Model\Cookie\CookieData;
use Amasty\GdprCookie\Model\CookiePolicy;
use Magento\Cms\Model\Template\Filter as CmsTemplateFilter;

class SideBar extends CommonTypeProcessor
{
    /**
     * @var CookieData
     */
    private $cookieData;

    public function __construct(
        ConfigProvider $configProvider,
        CookiePolicy $cookiePolicy,
        CmsTemplateFilter $cmsTemplateFilter,
        CookieData $cookieData
    ) {
        parent::__construct($configProvider, $cookiePolicy, $cmsTemplateFilter);
        $this->cookieData = $cookieData;
    }

    public function process(string $storeId): array
    {
        $result = parent::process($storeId);
        $result[0]['groups'] = $this->cookieData->getGroupData((int)$storeId)['groupData'];

        return $result;
    }

    protected function getCssConfig(string $storeId): array
    {
        $cssConfig = parent::getCssConfig($storeId);
        $cssConfig['textColor'] = $this->configProvider->getDescriptionTextColor($storeId);
        $cssConfig['titleColor'] = $this->configProvider->getTitleTextColor($storeId);

        return $cssConfig;
    }
}
