<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Gdpr Cookie Graphql by Amasty
 */

namespace Amasty\GdprCookieGraphql\Model\Resolver\Bar;

use Amasty\GdprCookieGraphql\Model\Resolver\Bar\Processor\TypeProcessorInterface;

class TypeProcessorProvider
{
    /**
     * @var TypeProcessorInterface[]
     */
    private $processors = [];

    /**
     * @param array $barTypes [ 'bar_type' => [
     * 'code' => 'bar', 'typeCode' => 0, 'processor' => ClassProcessor
     * ] ]
     */
    public function __construct(
        array $barTypes = []
    ) {
        $this->initializeBarTypes($barTypes);
    }

    /**
     * @return TypeProcessorInterface[]
     */
    public function getProcessors(): array
    {
        return $this->processors;
    }

    public function getProcessorByType(string $type): ?TypeProcessorInterface
    {
        return $this->processors[$type]['processor'] ?? null;
    }

    private function initializeBarTypes(array $fileTypes): void
    {
        foreach ($fileTypes as $processor) {
            if (!$processor['processor'] instanceof TypeProcessorInterface) {
                throw new \LogicException(
                    sprintf('Cookie Bar type must implement %s', TypeProcessorInterface::class)
                );
            }
            $this->processors[$processor['typeCode']] = $processor;
        }
    }
}
