<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Gdpr Cookie Graphql by Amasty
 */

namespace Amasty\GdprCookieGraphql\Model\Resolver;

use Amasty\GdprCookie\Model\ConfigProvider;
use Amasty\GdprCookieGraphql\Model\Resolver\Bar\TypeProcessorProvider;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;

class GetCookieBar implements ResolverInterface
{
    /**
     * @var ConfigProvider
     */
    private $configProvider;

    /**
     * @var TypeProcessorProvider
     */
    private $typeProcessorProvider;

    public function __construct(
        ConfigProvider $configProvider,
        TypeProcessorProvider $typeProcessorProvider
    ) {
        $this->configProvider = $configProvider;
        $this->typeProcessorProvider = $typeProcessorProvider;
    }

    public function resolve(Field $field, $context, ResolveInfo $info, array $value = null, array $args = null): ?array
    {
        if (!$this->configProvider->isCookieBarEnabled()) {
            return null;
        }

        $storeId = $context->getExtensionAttributes()->getStore()->getId();
        $type = $this->configProvider->getCookiePrivacyBarType();
        $processor = $this->typeProcessorProvider->getProcessorByType((string)$type);

        return $processor->process($storeId);
    }
}
