<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Gdpr Cookie Graphql by Amasty
 */

namespace Amasty\GdprCookieGraphql\Model\Resolver;

use Amasty\GdprCookie\Model\Cookie\CookieManagement;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;

class GetCookieGroups implements ResolverInterface
{
    /**
     * @var CookieManagement
     */
    private $cookieManagement;

    public function __construct(
        CookieManagement $cookieManagement
    ) {
        $this->cookieManagement = $cookieManagement;
    }

    public function resolve(
        Field $field,
        $context,
        ResolveInfo $info,
        array $value = null,
        array $args = null
    ): array {
        $storeId = (int)$context->getExtensionAttributes()->getStore()->getId();
        $result = [];
        foreach ($this->cookieManagement->getGroups($storeId) as $id => $group) {
            $result[$id]['id'] = $group->getId();
            $result[$id]['name'] = $group->getName();
            $result[$id]['description'] = $group->getDescription();
            $result[$id]['is_essential'] = $group->isEssential();
            $result[$id]['is_enabled'] = $group->isEnabled();
            $result[$id]['sort_order'] = $group->getSortOrder();
            $result[$id]['cookies'] = $this->getCookies($storeId, (int)$group->getId());
        }

        return $result;
    }

    private function getCookies(int $storeId, int $groupId): array
    {
        $cookies = [];
        foreach ($this->cookieManagement->getCookies($storeId, $groupId) as $id => $cookie) {
            $cookies[$id]['id'] = $cookie->getId();
            $cookies[$id]['name'] = $cookie->getName();
            $cookies[$id]['description'] = $cookie->getDescription();
            $cookies[$id]['is_enabled'] = $cookie->isEnabled();
            $cookies[$id]['provider'] = $cookie->getProvider();
            $cookies[$id]['cookie_type'] = $cookie->getType();
            $cookies[$id]['lifetime'] = $cookie->getLifetime();
            $cookies[$id]['group_id'] = $cookie->getGroupId();
        }

        return $cookies;
    }
}
