<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Gdpr Cookie Graphql by Amasty
 */

namespace Amasty\GdprCookieGraphql\Model\Resolver\Mutation;

use Amasty\GdprCookie\Model\ConfigProvider;
use Amasty\GdprCookie\Model\SaveCookiesConsent;
use Amasty\GdprCookie\Model\ResourceModel\CookieGroup as CookieGroupResource;
use Magento\Customer\Model\Session;
use Magento\CustomerGraphQl\Model\Customer\GetCustomer;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Exception\GraphQlInputException;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;

class LogCookieConsent implements ResolverInterface
{
    public const GROUP_IDS_KEY = 'group_ids';

    /**
     * @var GetCustomer
     */
    private $getCustomer;

    /**
     * @var Session
     */
    private $customerSession;

    /**
     * @var SaveCookiesConsent
     */
    private $saveCookiesConsent;

    /**
     * @var CookieGroupResource
     */
    private $groupResource;

    /**
     * @var ConfigProvider
     */
    private $configProvider;

    public function __construct(
        GetCustomer $getCustomer,
        Session $customerSession,
        SaveCookiesConsent $saveCookiesConsent,
        CookieGroupResource $groupResource,
        ConfigProvider $configProvider
    ) {
        $this->getCustomer = $getCustomer;
        $this->customerSession = $customerSession;
        $this->saveCookiesConsent = $saveCookiesConsent;
        $this->groupResource = $groupResource;
        $this->configProvider = $configProvider;
    }

    public function resolve(Field $field, $context, ResolveInfo $info, array $value = null, array $args = null): ?array
    {
        if (!$this->configProvider->isCookieBarEnabled()) {
            return null;
        }

        $input = $args['input'] ?? [];
        if (!isset($input[self::GROUP_IDS_KEY])) {
            throw new GraphQlInputException(__('PLeas specify Cookie Groups.'));
        }

        $storeId = (int)$context->getExtensionAttributes()->getStore()->getId();
        if ($input[self::GROUP_IDS_KEY] === '') {
            $allowedCookieGroupIds = [];
        } else {
            $this->groupResource->setStoreId($storeId);
            $enabledCookiesGroupIds = $this->groupResource->getEnabledGroupIds();
            $allowedCookieGroupIds = explode(',', $input[self::GROUP_IDS_KEY]);
            foreach ($allowedCookieGroupIds as $id) {
                if (!in_array($id, $enabledCookiesGroupIds)) {
                    throw new GraphQlInputException(__(
                        'Id "%1" is invalid or disabled. Please enter valid Cookie Group Ids.',
                        $id
                    ));
                }
            }
        }

        if (!$this->customerSession->getCustomerId()) {
            try {
                $customerId = (int)$this->getCustomer->execute($context)->getId();
            } catch (\Exception $e) {
                $customerId = 0;
            }
        } else {
            $customerId = (int)$this->customerSession->getCustomerId();
        }
        $result = $this->saveCookiesConsent->execute($allowedCookieGroupIds, $storeId, $customerId);

        return [
            'success' => $result['success'],
            'message' => $result['message']
        ];
    }
}
